# eric7.eric7_fido2

eric FIDO2 Token Management.

This is the main Python script that performs the necessary initialization of the FIDO2 Security Key Management module and starts the Qt event loop. This is a standalone version of the integrated FIDO2 Security Key Management module.

### Global Attributes

args

### Classes

None

### Functions

createArgparseNamespace | Function to create an argument parser.
createMainWidget | Function to create the main widget.
main | Main entry point into the application.

## createArgparseNamespace

createArgparseNamespace()

Function to create an argument parser.

Return:
  created argument parser object

Return Type:
  argparse.ArgumentParser

Up

## createMainWidget

createMainWidget(_args)

Function to create the main widget.

_args (argparse.Namespace)
  namespace object containing the parsed command line parameters (unused)

Return:
  reference to the main widget

Return Type:
  QWidget

Up

## main

main()

Main entry point into the application.

Up